@@ -798,15 +798,6 @@ class Search(Call):
     * Matches found in ``events`` originate from the initial (non source-only) user upload (and thus are local builds).
     """
 
-    @classmethod
-    def iarguments(cls):
-        yield StrArgument(["pattern"],
-                          doc=(
-                              "Pattern for binary or source package name.\n"
-                              "\n"
-                              "Value is a glob pattern; '*' is added automatically to begin and end of the pattern."
-                          ))
-
     EMPTY_RESULT = {
         "repositories": [],
         "builds": [],
@@ -819,29 +810,40 @@ class Search(Call):
         "events": "Be cautious: Binary package originates from user upload (local build)",
     }
 
-    def _run(self):
-        self.result = {}
+    @classmethod
+    def iarguments(cls):
+        yield StrArgument(["pattern"],
+                          doc=(
+                              "Pattern for binary or source package name.\n"
+                              "\n"
+                              "Value is a glob pattern; '*' is added automatically to begin and end of the pattern."
+                          ))
 
-        pattern = "*" + self.args["pattern"].value() + "*"
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self.pattern = None
+
+    def _run(self):
+        self.pattern = "*" + self.args["pattern"].value().lower() + "*"
 
         # Search in repositories
         repositories_route = config.ROUTES["repositories"]
         for repository in util.models().Repository.objects.all():
-            for src, file_name in repository.mbd_reprepro.pool.isearch(pattern):
+            for src, file_name in repository.mbd_reprepro.pool.isearch(self.pattern):
                 self.result.setdefault(src, copy.deepcopy(self.EMPTY_RESULT))
                 self.result[src]["repositories"].append(str(file_name.relative_to(repositories_route.path.full)))
 
         # Search in builds
         builds_route = config.ROUTES["builds"]
         builds_path = pool.Dir(pathlib.Path(builds_route.path.full), pooldir="", sources_glob="*")
-        for src, file_name in builds_path.isearch(pattern):
+        for src, file_name in builds_path.isearch(self.pattern):
             self.result.setdefault(src, copy.deepcopy(self.EMPTY_RESULT))
             self.result[src]["builds"].append(str(file_name.relative_to(builds_route.path.full)))
 
         # Search in events
         events_route = config.ROUTES["events"]
         events_path = pool.Dir(pathlib.Path(events_route.path.full), pooldir="", sources_glob="*")
-        for src, file_name in events_path.isearch(pattern):
+        for src, file_name in events_path.isearch(self.pattern):
             self.result.setdefault(src, copy.deepcopy(self.EMPTY_RESULT))
             self.result[src]["events"].append(str(file_name.relative_to(events_route.path.full)))
 
